package Evo::Loaded;
use Evo;
use Module::Loaded;

sub import { mark_as_loaded(scalar caller) }

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Evo::Loaded

=head1 VERSION

version 0.0173

=head1 DESCRIPTION

Mark module as loaded

=head1 SYNOPSYS

  package main;
  use Evo;

  {

    package Foo;
    use Evo -Loaded;
  };

  # now use can use this without "Can't find module..."
  use Foo;

=head1 AUTHOR

alexbyk.com

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by alexbyk.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
